@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw( Alien::Base );
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 
 1;
@@ -22,7 +22,7 @@ Alien::proj - Compile the PROJ library
 <p>
     <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
     <a href="https://travis-ci.org/shawnlaffan/perl-alien-proj4"><img src="https://travis-ci.org/shawnlaffan/perl-alien-proj4.svg?branch=master" /></a>
-    <a href="https://ci.appveyor.com/project/shawnlaffan/perl-alien-proj4"><img src="https://ci.appveyor.com/api/projects/status/1tqk5rd40cv2ve8q?svg=true" /></a>
+    <a href="https://ci.appveyor.com/project/shawnlaffan/perl-alien-proj4"><img src="https://ci.appveyor.com/api/projects/status/3lv9qu9ea2ex3p5d?svg=true" /></a>
 </p>
 
 =end HTML
@@ -31,14 +31,14 @@ Alien::proj - Compile the PROJ library
 
     use Alien::proj4;
 
-    use Env qw(@PATH);
-    unshift @PATH, Alien::proj4->bin_dir;
-
     
 =head1 DESCRIPTION
 
 PROJ is a generic coordinate transformation software.  See L<https://proj4.org/about.html>.
 
+This Alien package is probably most useful for compilation of other modules, e.g. L<Geo::GDAL::FFI>.
+
+The Proj library can be accessed from Perl code via the L<Geo::Proj4> package.  
 
 =head1 REPORTING BUGS
 
@@ -47,12 +47,13 @@ L<https://github.com/shawnlaffan/perl-alien-proj4/issues>.
 
 =head1 SEE ALSO
 
-L<Geo::GDAL>
+L<Geo:Proj4>
 
 L<Geo::GDAL::FFI>
 
 L<Alien::geos::af>
 
+
 =head1 AUTHORS
 
 Shawn Laffan, E<lt>shawnlaffan@gmail.comE<gt>
